
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '32.8.5',
    'branch_nick': 'release-32-LTS',
    'revision_id': '79ad5881f1eb38a11b0df6a16f35cbf0d8872f5b',
    'revno': 12663
}
